summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextParag.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /lib/kotext/KoTextParag.h
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'lib/kotext/KoTextParag.h')
-rw-r--r--lib/kotext/KoTextParag.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kotext/KoTextParag.h b/lib/kotext/KoTextParag.h
index e27a9afc..591242a2 100644
--- a/lib/kotext/KoTextParag.h
+++ b/lib/kotext/KoTextParag.h
@@ -130,8 +130,8 @@ public:
void setFormat( int index, int len, const KoTextFormat *f, bool useCollection = TRUE, int flags = -1 );
- void tqsetAlignment( uint a );
- void tqsetAlignmentDirect( uint a ) { align = a; }
+ void setAlignment( uint a );
+ void setAlignmentDirect( uint a ) { align = a; }
uint tqalignment() const;
virtual void paint( TQPainter &painter, const TQColorGroup &cg, KoTextCursor *cursor, bool drawSelections,
@@ -235,7 +235,7 @@ public:
void setLineSpacingType( KoParagLayout::SpacingType _type );
/** Use this to change the paragraph tqalignment, not KoTextParag::tqsetAlignment ! */
void setAlign( int align );
/** Return the real tqalignment: Auto is resolved to either Left or Right */
int resolveAlignment() const;
@@ -520,7 +520,7 @@ inline KoTextDocument *KoTextParag::document() const
return doc;
}
-inline void KoTextParag::tqsetAlignment( uint a )
+inline void KoTextParag::setAlignment( uint a )
{
if ( a == align )
return;
@@ -235,7 +235,7 @@ public:
void setLineSpacingType( KoParagLayout::SpacingType _type );
- /** Use this to change the paragraph tqalignment, not KoTextParag::tqsetAlignment ! */
+ /** Use this to change the paragraph tqalignment, not KoTextParag::setAlignment ! */
void setAlign( int align );
/** Return the real tqalignment: Auto is resolved to either Left or Right */